@@ -1,16 +1,10 @@
 require 'spec_helper_acceptance'
 
-describe 'apt class' do
+MAX_TIMEOUT_RETRY              = 3
+TIMEOUT_RETRY_WAIT             = 5
+TIMEOUT_ERROR_MATCHER = %r{no valid OpenPGP data found}
 
-  context 'reset' do
-    it 'fixes the sources.list' do
-      shell('cp /etc/apt/sources.list /tmp')
-    end
-  end
-
-  context 'all the things' do
-    it 'should work with no errors' do
-      pp = <<-EOS
+everything_everything_pp = <<-MANIFEST
       if $::lsbdistcodename == 'lucid' {
         $sources = undef
       } else {
@@ -20,7 +14,7 @@ describe 'apt class' do
             'location' => 'http://apt.puppetlabs.com',
             'repos'    => 'main',
             'key'      => {
-              'id'     => '47B320EB4C7C375AA9DAE1A01054B7A24BD6EC30',
+              'id'     => '6F6B15509CF8E59E6E469F327F438280EF8D349F',
               'server' => 'hkps.pool.sks-keyservers.net',
             },
           },
@@ -29,8 +23,8 @@ describe 'apt class' do
       class { 'apt':
         update => {
           'frequency' => 'always',
-          'timeout'   => '400',
-          'tries'     => '3',
+          'timeout'   => 400,
+          'tries'     => 3,
         },
         purge => {
           'sources.list'   => true,
@@ -40,21 +34,33 @@ describe 'apt class' do
         },
         sources => $sources,
       }
-      EOS
+  MANIFEST
 
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_failures => true)
+describe 'apt class' do
+  context 'with reset' do
+    it 'fixes the sources.list' do
+      shell('cp /etc/apt/sources.list /tmp')
     end
-    it 'should still work' do
+  end
+
+  context 'with all the things' do
+    it 'works with no errors' do
+      # Apply the manifest (Retry if timeout error is received from key pool)
+      retry_on_error_matching(MAX_TIMEOUT_RETRY, TIMEOUT_RETRY_WAIT, TIMEOUT_ERROR_MATCHER) do
+        apply_manifest(everything_everything_pp, catch_failures: true)
+      end
+
+      apply_manifest(everything_everything_pp, catch_failures: true)
+    end
+    it 'stills work' do
       shell('apt-get update')
       shell('apt-get -y --force-yes upgrade')
     end
   end
 
-  context 'reset' do
+  context 'with reset' do
     it 'fixes the sources.list' do
       shell('cp /tmp/sources.list /etc/apt')
     end
   end
-
 end
